@@ -57,92 +57,149 @@ static double weights[] =
      10.0000, // test 3
      87.3703, // ...
      10.0000, 
-     150.0000,
+   
+     150.0000, // test 6
      10.0000,
      150.0000,
      10.0000,
      150.0000,
-     10.0000,
+   
+     10.0000, // test 11
      150.0000,
      10.0000,
      10.6493, 
      38.4818,
-     40.7314,
+   
+     40.7314, // test 16
      32.0866,
      21.3337,
      21.2167,
      71.6141,
-     64.8893,
+   
+     64.8893, // test 21
      95.0880,
      121.0438,
      41.2646,
      162.7149,
-     89.1650,
+   
+     89.1650, // test 26
      105.3571,
      40.9657,
      98.4671,
      28.4322,
-     60.000,
+   
+     60.000, // test 31
      75.5507,
      51.6601,
      135.4753,
      38.2705,
-     35.9915,
+   
+     35.9915, // test 36
      31.9500,
      22.6752,
      38.2702,
      37.4459,
-     37.2009,
+   
+     37.2009, // test 41
      34.5459,
      38.5043,
      50.0000,
      37.0282,
-     55.8886,
+   
+     55.8886, // test 46
      17.2535,
      23.1457,
      36.9874,
      37.9336,
-     17.1830,
+   
+     17.1830, // test 51
      20.7521,
      29.0141,
      131.6784,
      13.6851,
-     23.4462,
+   
+     23.4462, // test 56
      14.7573,
      36.5261,
       5.0000,
       5.0000,
-     24.3482,
+   
+     24.3482, // test 61
      10.4611,
      86.0290,
      82.0735,
      18.6459,
-     37.4608,
+   
+     37.4608, // test 66
      32.4417,
      11.5449,
+      5.0000,
      11.4172,
-     13.3682,
+   
+     13.3682, // test 71
      10.0324,
      10.0584,
      10.0170,
      5.4029,
-     10.6349,
+   
+     10.6349, // test 76
      21.7728,
      12.7933,
      19.4177,
      34.4192,
-     23.9110,
+   
+     23.9110, // test 81
      22.8287,
      41.2399,
      30.1383,
      22.0342,
-     38.2952,
+   
+     38.2952, // test 86
      5.5560,
      0.5000,
+     1.000,
+     10.000,
+   
+     5.000, // test 91
+     20.000, // MASK
+     20.000, // MASK 2
+     20.000, // MASK 3
+     20.000, // MASK 4
+   
+     20.000, // test 96
+     20.000, // MASK 6
+     20.000, // MASK 7
+     20.000, // MASK 8
+     20.000, // MASK 9
+   
+     20.000, // test 101
+     20.000, // MASK 11
+     20.000, // MASK 12
+     20.000, // MASK 13
+     20.000, // MASK 14
+   
+     20.000, // test 106 MASK 15
+     1.000,
+     2.000,
+     1.000,
+     2.000,
+
+     1.000, // test 111
+     2.000,
+     1.000,
+     2.000,
+     1.000,
+
+     2.000,   // test 116
+     10.000,
+     10.000,
+   
+     0.0, // Exit
    
      0.0, // no final test - add a 0 at the end anyway to pad
      0.0,
      0.0,
+     0.0,
      0.0
 };
 
@@ -172,8 +229,8 @@ _ui_all(void)
    Eina_List *l;
    double fps = 0.0;
    double wfps = 0.0;
-   int t_count = 0;
-   int i;
+   unsigned int t_count = 0;
+   unsigned int i;
    double avgw = 0.0;
 
    evas_object_hide(o_menu_logo);
@@ -211,7 +268,10 @@ _ui_all(void)
         wfps += (p_fps * weights[t_count]);
 	key_func("Escape");
      }
-   for (i = 1; i < ((sizeof(weights) / sizeof(double)) - 1); i++)
+   for (i = 1; 
+        (i < (1 + t_count)) &&
+        (weights[i] > 0.0);
+        i++)
      avgw += weights[i];
    avgw /= (i - 1);
    if (t_count > 0)
@@ -222,7 +282,7 @@ _ui_all(void)
         
         now = time(NULL);
         tim = localtime(&now);
-        if (tim) strftime(datestr, sizeof(datestr), "%F %T", tim);
+        if (tim) strftime(datestr, sizeof(datestr), "%Y-%m-%d %H:%M:%S", tim);
         else snprintf(datestr, sizeof(datestr), "unknown");
 //        printf("%5.2f , EVAS SPEED\n", fps / t_count);
         printf("%5.2f , EVAS SPEED (WEIGHTED), "
@@ -257,7 +317,7 @@ _ui_num(int n)
    double wfps = 0.0;
    int t_count = 0;
    Menu_Item *mi;
-   int i;
+   unsigned int i;
    double avgw = 0.0;
 
    evas_object_hide(o_menu_logo);
@@ -335,7 +395,7 @@ _ui_select(void)
 }
 
 static void
-_ui_key(void *data, Evas *e, Evas_Object *obj, void *event_info)
+_ui_key(void *data __UNUSED__, Evas *e __UNUSED__, Evas_Object *obj __UNUSED__, void *event_info)
 {
    Evas_Event_Key_Down *ev;
 
@@ -356,18 +416,17 @@ _ui_key(void *data, Evas *e, Evas_Object *obj, void *event_info)
 	if (!strcmp(ev->keyname, "Left")) menu_sel++;
 	if (!strcmp(ev->keyname, "Right")) menu_sel--;
 	if (menu_sel < 0) menu_sel = 0;
-	else if (menu_sel >= eina_list_count(menu)) menu_sel = eina_list_count(menu) - 1;
+	else if ((unsigned int)menu_sel >= eina_list_count(menu)) menu_sel = eina_list_count(menu) - 1;
 	menu_anim_sel = menu_sel;
 	if (!strcmp(ev->keyname, "Return")) _ui_select();
      }
 }
 
 static Evas_Coord down_x, down_y;
-static int down = 0;
 static int down_menu_sel = 0;
 
 static void
-_ui_mouse_down(void *data, Evas *e, Evas_Object *obj, void *event_info)
+_ui_mouse_down(void *data __UNUSED__, Evas *e __UNUSED__, Evas_Object *obj __UNUSED__, void *event_info)
 {
    Evas_Event_Mouse_Down *ev;
 
@@ -375,18 +434,14 @@ _ui_mouse_down(void *data, Evas *e, Evas_Object *obj, void *event_info)
    if (ev->button != 1) return;
    if (menu_active)
      {
-	down_x = ev->canvas.x;
-	down_y = ev->canvas.y;
-	down++;
-	down_menu_sel = menu_sel;
-     }
-   else
-     {
+        down_x = ev->canvas.x;
+        down_y = ev->canvas.y;
+        down_menu_sel = menu_sel;
      }
 }
 
 static void
-_ui_mouse_up(void *data, Evas *e, Evas_Object *obj, void *event_info)
+_ui_mouse_up(void *data __UNUSED__, Evas *e __UNUSED__, Evas_Object *obj __UNUSED__, void *event_info)
 {
    Evas_Event_Mouse_Up *ev;
 
@@ -394,39 +449,36 @@ _ui_mouse_up(void *data, Evas *e, Evas_Object *obj, void *event_info)
    if (ev->button != 1) return;
    if (menu_active)
      {
-	Evas_Coord dx, dy;
+        Evas_Coord dx, dy;
 
-	dx = ev->canvas.x - down_x;
-	dy = ev->canvas.y - down_y;
-	if ((((dx * dx) + (dy * dy)) < (20 * 20)) &&
-	    (menu_sel == down_menu_sel))
-	  _ui_select();
-	down--;
+        dx = ev->canvas.x - down_x;
+        dy = ev->canvas.y - down_y;
+        if ((((dx * dx) + (dy * dy)) < (20 * 20)) &&
+            (menu_sel == down_menu_sel))
+          _ui_select();
      }
    else
      {
-	evas_event_feed_key_down(evas, "Escape", "Escape", NULL, NULL, 0, NULL);
-	evas_event_feed_key_up(evas, "Escape", "Escape", NULL, NULL, 0, NULL);
+        evas_event_feed_key_down(evas, "Escape", "Escape", NULL, NULL, 0, NULL);
+        evas_event_feed_key_up(evas, "Escape", "Escape", NULL, NULL, 0, NULL);
      }
 }
 
 static void
-_ui_mouse_move(void *data, Evas *e, Evas_Object *obj, void *event_info)
+_ui_mouse_move(void *data __UNUSED__, Evas *e __UNUSED__, Evas_Object *obj __UNUSED__, void *event_info)
 {
    Evas_Event_Mouse_Move *ev;
 
    ev = event_info;
-   if (!down) return;
+   if (ev->buttons != 1) return;
    if (menu_active)
      {
-	menu_sel = down_menu_sel + ((ev->cur.canvas.x - down_x) / 25);
-	/* scroll */
-	if (menu_sel < 0) menu_sel = 0;
-	else if (menu_sel >= eina_list_count(menu)) menu_sel = eina_list_count(menu) - 1;
-	menu_anim_sel = menu_sel;
-     }
-   else
-     {
+        menu_sel = down_menu_sel + ((ev->cur.canvas.x - down_x) / 25);
+        /* scroll */
+        if (menu_sel < 0) menu_sel = 0;
+        else if ((unsigned int)menu_sel >= eina_list_count(menu))
+          menu_sel = eina_list_count(menu) - 1;
+        menu_anim_sel = menu_sel;
      }
 }
 
@@ -551,16 +603,21 @@ _ui_setup(void)
 #undef UI
    _ui_menu_item_add("exit.png", "Exit", _ui_exit);
 
+#ifdef HAVE_SYNC
    /* make sure disk io isn't going to turn up unexpectedly */
    sync();
    sync();
    sync();
+#endif
    /* warm up the cpu with some spinning */
-   t0 = time(NULL);
-   for (;;)
+   if (run_all)
      {
-        t = time(NULL);
-        if (t - t0 > 2) break;
+        t0 = time(NULL);
+        for (;;)
+          {
+             t = time(NULL);
+             if (t - t0 > 2) break;
+          }
      }
 
    if (run_all)
